AiClient class

Constructors

AiClient(AiConfig config)

Properties

config AiConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

complete({required String prompt, AiLanguage language = AiLanguage.auto, bool autoDetectLanguage = false}) Future<AiResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(PromptTemplate template) Future<AiResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited