AiLanguage enum
Values
- auto → const AiLanguage
-
const AiLanguage("the same language as the user input") - english → const AiLanguage
-
const AiLanguage("English") - bengali → const AiLanguage
-
const AiLanguage("Bengali") - arabic → const AiLanguage
-
const AiLanguage("Arabic") - hindi → const AiLanguage
-
const AiLanguage("Hindi") - spanish → const AiLanguage
-
const AiLanguage("Spanish") - french → const AiLanguage
-
const AiLanguage("French") - german → const AiLanguage
-
const AiLanguage("German") - chinese → const AiLanguage
-
const AiLanguage("Chinese") - japanese → const AiLanguage
-
const AiLanguage("Japanese")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AiLanguage> - A constant List of the values in this enum, in order of their declaration.